@@ -2,8 +2,8 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-26 17:51:04
-:LastEditTime: 2021-04-27 11:17:28
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-08-12 15:19:46
+@LastEditors: HuangJianYi
 :Description: 抽奖
 """
 import operator
@@ -112,7 +112,7 @@ class LotteryHandler(SevenBaseHandler):
             sale_date_str = str(machine_info.sale_date)
             sale_date = TimeHelper.format_time_to_datetime(sale_date_str if sale_date_str != "1900-01-01 00:00:00" else now_date)
             if TimeHelper.format_time_to_datetime(now_date) < sale_date:
-                china_sale_date = sale_date.month + "月" + sale_date.day + "日" + sale_date.hour + "点"
+                china_sale_date = str(sale_date.month) + "月" + str(sale_date.day) + "日" + str(sale_date.hour) + "点"
                 return self.reponse_json_error("NoStart", "该商品" + china_sale_date + "开售,敬请期待~")
 
         price_gear_model = PriceGearModel(context=self)
