@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-01 17:17:43
+@LastEditTime: 2021-09-02 10:48:07
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -597,7 +597,7 @@ class GivePropHandler(SevenBaseHandler):
         prop_log.prop_type = prop_type
         prop_log.operate_value = -1
         prop_log.history_value = history_value
-        prop_log.title = "道具赠送"
+        prop_log.title = "转赠"
         prop_log.create_date_int = SevenHelper.get_now_day_int()
         prop_log.create_date = self.get_now_datetime()
         info = {}
@@ -709,7 +709,7 @@ class GetPropGiveHandler(SevenBaseHandler):
         prop_log.prop_type = prop_give.prop_type
         prop_log.operate_value = 1
         prop_log.history_value = history_value
-        prop_log.title = "领取赠送"
+        prop_log.title = "领取"
         prop_log.create_date_int = SevenHelper.get_now_day_int()
         prop_log.create_date = self.get_now_datetime()
         info = {}
