@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-@LastEditTime: 2021-05-12 11:19:39
+@LastEditTime: 2021-08-31 18:14:07
 @LastEditors: HuangJianYi
 :description: 基础接口
 """
@@ -63,7 +63,7 @@ class ActCreateHandler(TopBaseHandler):
         skin_info_model = SkinInfoModel(context=self)
         ip_series_model = IpSeriesModel(context=self)
         act_type_model = ActTypeModel(context=self)
-        theme_info = theme_info_model.get_entity()
+        theme_info = theme_info_model.get_entity("app_id=%s or app_id=''", order_by="id desc", params=[app_id])
         if not theme_info:
             return self.reponse_json_error("NoTheme", "请管理员先上传主题信息")
         act_type_entity = act_type_model.get_entity_by_id(act_type)
@@ -231,6 +231,7 @@ class ActHandler(SevenBaseHandler):
         :param act_id：活动id
         :param act_name：活动名称
         :param is_release：是否发布
+        :param theme_id：主题标识
         :param close_word：关闭小程序文案
         :param share_desc：分享配置
         :param rule_desc：规则配置
@@ -247,6 +248,7 @@ class ActHandler(SevenBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         act_name = self.get_param("act_name")
         is_release = int(self.get_param("is_release", 0))
+        theme_id = self.get_param("theme_id")
         close_word = self.get_param("close_word")
         share_desc = self.get_param("share_desc", "")
         rule_desc = self.get_param("rule_desc", "")
@@ -274,6 +276,7 @@ class ActHandler(SevenBaseHandler):
             act_info.index_desc = self.json_dumps(index_desc) if index_desc != "" else {}
             act_info.shakebox_tips = self.json_dumps(shakebox_tips) if shakebox_tips != "" else []
             act_info.shakebox_tips_num = shakebox_tips_num
+            act_info.theme_id = theme_id if theme_id != "" else act_info.theme_id
             act_info.exceed_tips = exceed_tips
             act_info.is_black = is_black
             act_info.is_task = is_task
@@ -299,6 +302,7 @@ class ActSaveHandler(SevenBaseHandler):
         :param act_id：活动id
         :param act_name：活动名称
         :param is_release：是否发布
+        :param theme_id：主题标识
         :param close_word：关闭小程序文案
         :param share_desc：分享配置
         :param rule_desc：规则配置
@@ -320,6 +324,7 @@ class ActSaveHandler(SevenBaseHandler):
         rule_desc = self.get_param("rule_desc", "")
         is_black = self.get_param("is_black", "")
         is_task = self.get_param("is_task", "")
+        theme_id = self.get_param("theme_id")
         refund_count = self.get_param("refund_count", "")
         store_url = self.get_param("store_url", "")
         index_desc = self.get_param("index_desc", "")
@@ -355,6 +360,8 @@ class ActSaveHandler(SevenBaseHandler):
                 act_info.is_black = int(is_black)
             if is_task:
                 act_info.is_task = int(is_task)
+            if theme_id:
+                act_info.theme_id = int(theme_id)
             if refund_count:
                 act_info.refund_count = int(refund_count)
             if store_url:
