@@ -2,8 +2,8 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-29 09:40:42
-@LastEditTime: 2021-05-28 16:21:09
-@LastEditors: HuangJianYi
+@LastEditTime: 2021-06-21 15:53:38
+@LastEditors: WangQiang
 :description: 机台（盒子）
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -19,6 +19,7 @@ from seven_cloudapp.handlers.server.machine_s import CheckBuyEndboxHandler
 
 from seven_cloudapp_ppmt.models.db_models.machine.machine_info_model import *
 from seven_cloudapp_ppmt.models.db_models.act.act_prize_model import *
+from seven_cloudapp_ppmt.models.db_models.act.act_info_model import *
 
 
 class MachineHandler(SevenBaseHandler):
@@ -215,7 +216,6 @@ class UpdateMachinePriceByGearIdHandler(SevenBaseHandler):
     """
     :description: 更新机台价格，通过档位id
     """
-    @filter_check_params("machine_id")
     def get_async(self):
         """
         :description: 更新机台价格，通过档位id
@@ -232,10 +232,60 @@ class UpdateMachinePriceByGearIdHandler(SevenBaseHandler):
 
         price_gear_model = PriceGearModel(context=self)
         price_gear = price_gear_model.get_dict_by_id(gear_id)
-        if not price_gear or price_gear["act_id"]!= act_id:
-            return self.reponse_json_error("Error","价格档位不存在")
+        if not price_gear or price_gear["act_id"] != act_id:
+            return self.reponse_json_error("Error", "价格档位不存在")
 
         machine_info_model = MachineInfoModel(context=self)
-        machine_info_model.update_table("machine_price=%s", "act_id=%s and price_gears_id=%s", params=[price_gear["price"], act_id,gear_id])
+        machine_info_model.update_table("machine_price=%s", "act_id=%s and price_gears_id=%s", params=[price_gear["price"], act_id, gear_id])
 
-        return self.reponse_json_success()
\ No newline at end of file
+        return self.reponse_json_success()
+
+
+class CheckingPriceGearHandler(SevenBaseHandler):
+    """
+    :description: 验证价格档位
+    """
+    @filter_check_params("goods_id,act_id")
+    def get_async(self):
+        """
+        :description: 验证价格档位
+        :param goods_id：商品id
+        :param act_id：活动id
+        :param price_gear_id：价格档位id
+        :return: reponse_json_success
+        :last_editors: WangQiang
+        """
+
+        app_id = self.get_param("app_id")
+        goods_id = self.get_param("goods_id", "")
+        sku_id = self.get_param("sku_id", "")  #不传，则为无SKU绑定
+        act_id = int(self.get_param("act_id", "0"))
+        price_gear_id = int(self.get_param("price_gear_id", "0"))
+        price_gear_model = PriceGearModel(context=self)
+        condtion = "app_id=%s and goods_id=%s"
+        params = [app_id, goods_id]
+        if price_gear_id > 0:
+            condtion += " and id!=%s"
+            params.append(price_gear_id)
+        price_gear_dict_list = price_gear_model.get_dict_list(condtion, params=params)
+        is_fail = False
+        bind_act_id = 0
+        if price_gear_dict_list:
+            if not sku_id:
+                is_fail = True
+                bind_act_id = price_gear_dict_list[0]["act_id"]
+            else:
+                for price_gear_dict in price_gear_dict_list:
+                    if price_gear_dict["relation_type"] == 1 or price_gear_dict["sku_id"] == sku_id:
+                        is_fail = True
+                        bind_act_id = int(price_gear_dict["act_id"])
+                        break
+        #验证失败
+        if is_fail == True:
+            if act_id == bind_act_id:
+                return self.reponse_json_error("Bound", "对不起,该商品已绑定其他价格档位")
+            else:
+                act_info = ActInfoModel(context=self).get_entity_by_id(bind_act_id)
+                if act_info:
+                    return self.reponse_json_error("Bound", "对不起,该商品已绑定" + act_info.act_name + "活动")
+        self.reponse_json_success()
\ No newline at end of file
